<?php
/**
 * @package		OpenCart
 * @author		Johan@Reynaert.be
 * @copyright	Copyright (c) 2022 (https://www.reynaert.be/)
 * @license		https://opensource.org/licenses/GPL-3.0
 * @link		https://www.reynaert.be
*/

/**
* Reynaert class
*/
class Reynaert {

    /**
     * replace text - $this->request->server['REMOTE_ADDR'] with \Reynaert::getRealClientIP() in php files - no vqmod, but real overwrite
     * I could have coded a search in all the files, but I didn't.
     * made for version 3.0.3.8
     */
	public static function upgrade() {
        // first round: isset
        $files = [
            "catalog/controller/product/search.php",
            "catalog/controller/extension/payment/bluepay_redirect.php",
            "catalog/controller/extension/payment/squareup.php",
            "catalog/controller/common/footer.php",
        ];
        foreach ($files as $file) {
            $filename = $_SERVER['DOCUMENT_ROOT'] . "/" . $file;
            if (is_file($filename)) {
                $txt = file_get_contents($filename);
                $len = strlen($txt);
                $txt = str_replace('isset($this->request->server[\'REMOTE_ADDR\'])', 'true', $txt);
                if ($len != strlen($txt))
                    file_put_contents($filename, $txt);
            }
        }
        // second round: actual replacement
        $files = [
            "system/library/cart/customer.php",
            "system/library/cart/user.php",
            "catalog/model/extension/payment/amazon_login_pay.php",
            "catalog/model/account/activity.php",
            "catalog/model/account/customer.php",
            "catalog/controller/startup/session.php",
            "catalog/controller/product/search.php",
            "catalog/controller/mail/forgotten.php",
            "catalog/controller/extension/payment/authorizenet_aim.php",
            "catalog/controller/extension/payment/authorizenet_sim.php",
            "catalog/controller/extension/payment/bluepay_redirect.php",
            "catalog/controller/extension/payment/eway.php",
            "catalog/controller/extension/payment/klarna_checkout.php",
            "catalog/controller/extension/payment/perpetual_payments.php",
            "catalog/controller/extension/payment/pilibaba.php",
            "catalog/controller/extension/payment/pp_braintree.php",
            "catalog/controller/extension/payment/pp_express.php",
            "catalog/controller/extension/payment/pp_payflow.php",
            "catalog/controller/extension/payment/pp_pro.php",
            "catalog/controller/extension/payment/squareup.php",
            "catalog/controller/extension/module/paypal_smart_button.php",
            "catalog/controller/extension/captcha/google.php",
            "catalog/controller/common/footer.php",
            "catalog/controller/api/login.php",
            "catalog/controller/api/order.php"
        ];

        foreach ($files as $file) {
            $filename = $_SERVER['DOCUMENT_ROOT'] . "/" . $file;
            if (is_file($filename)) {
                $txt = file_get_contents($filename);
                $len = strlen($txt);
                $txt = str_replace('$this->request->server[\'REMOTE_ADDR\']', '\Reynaert::getRealClientIP()', $txt);
                if ($len != strlen($txt))
                    file_put_contents($filename, $txt);
            }
        }
        // part 3: inject reynaert::ob after startup
        $filename = $_SERVER['DOCUMENT_ROOT'] . "/index.php";
        $txt = file_get_contents($filename);
        if (strpos($txt, 'Reynaert')===false) {
            $txt = str_replace('require_once(DIR_SYSTEM . \'startup.php\');', 'require_once(DIR_SYSTEM . \'startup.php\');
// SEO rewrite - parse final HTML, change some text/links just before spitting this out
\Reynaert::ob();', $txt);
            file_put_contents($filename, $txt);
        }
	}
	public static function getRealClientIP() {
		if (!empty($_SERVER['HTTP_CLIENT_IP'])) //check ip from share internet
			return $_SERVER['HTTP_CLIENT_IP'];
		elseif (!empty($_SERVER['HTTP_X_FORWARDED_FOR']))  //to check ip is pass from proxy
			return $_SERVER['HTTP_X_FORWARDED_FOR'];
		elseif (isset($_SERVER['REMOTE_ADDR']))
			return $_SERVER['REMOTE_ADDR'];
		else
		    return '';
	}

    /**
     * SEO at its most simple form
     * note that for every replacement you need to make an SEO-url -> /admin/index.php?route=design/seo_url
     */
    public static function ob() {
	    if (!isset($_GET['route']) || $_GET['route']!=='extension/feed/google_sitemap')
		    ob_start("self::ob_html_seo");
	}
	public static function ob_html_seo($buf){
		return str_replace(
			[
				"https://shop.aquanav.be/",
				"index.php?route=common/home",
				"index.php?route=product/search",
				"index.php?route=checkout/success",
				"index.php?route=checkout/checkout/country",
				"index.php?route=checkout/checkout",
				"index.php?route=checkout/cart/add",
				"index.php?route=checkout/cart",
				"index.php?route=information/contact",
				"index.php?route=account/return/add",
				"index.php?route=information/sitemap",
				"index.php?route=product/manufacturer",
				"index.php?route=account/voucher",
				"index.php?route=affiliate/login",
				"index.php?route=product/special",
				"index.php?route=account/account/country",
				"index.php?route=account/account",
				"index.php?route=account/login",
				"index.php?route=account/order/info",
				"index.php?route=account/order/reorder",
				"index.php?route=account/order",
				"index.php?route=account/wishlist",
				"index.php?route=account/newsletter",
				"index.php?route=account/register",
				"index.php?route=account/edit",
				"index.php?route=account/password",
				"index.php?route=account/download",
				"index.php?route=account/forgotten",
				"index.php?route=account/address/edit",
				"index.php?route=account/address/add",
				"index.php?route=account/address/delete",
				"index.php?route=account/address",
				"index.php?route=account/recurring",
				"index.php?route=account/reward",
				"index.php?route=account/return/info",
				"index.php?route=account/return",
				"index.php?route=account/transaction",
				"index.php?route=account/affiliate/add",
				"index.php?route=product/compare",
				"index.php?route=common/currency/currency"
			],
			[
				"/",
				"",
				"search",
				"checkout-succes",
				"checkout-country",
				"checkout",
				"cart-add",
				"cart",
				"contact",
				"account-return-add",
				"sitemap",
				"brands",
				"account-voucher",
				"affiliate-login",
				"product-specials",
				"my-account-country",
				"my-account",
				"account-login",
				"my-orders-info",
				"my-orders-reorder",
				"my-orders",
				"my-wishlist",
				"account-newsletter",
				"account-register",
				"account-edit",
				"account-password",
				"my-downloads",
				"account-forgotten",
				"account-address-edit",
				"account-address-add",
				"account-address-delete",
				"account-address",
				"account-recurring",
				"account-reward",
				"account-returns-info",
				"account-returns",
				"account-transaction",
				"account-affiliate-add",
				"product-commpare",
				"common-currency-change"
			], 
			$buf);
	}
}
